
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.14.3'
version = '1.14.3'
full_version = '1.14.3'
git_revision = '4671d0701f27f3ba8f97cdf0dc8d7e40d5ba9591'
release = True

if not release:
    version = full_version
